#ifndef _STM32YYXX_LL_FMPI2C_H_
#define _STM32YYXX_LL_FMPI2C_H_
/* LL raised several warnings, ignore them */
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wunused-parameter"
#pragma GCC diagnostic ignored "-Wstrict-aliasing"

#ifdef STM32F4xx
  #include "stm32f4xx_ll_fmpi2c.h"
#endif
#pragma GCC diagnostic pop
#endif /* _STM32YYXX_LL_FMPI2C_H_ */
